# Actions

::: mountaineer.actions.passthrough.passthrough
    options:
      members:
        - register
      show_source: false
      show_root_heading: true

::: mountaineer.actions.sideeffect.sideeffect
    options:
      members:
        - register
      show_source: false
      show_root_heading: true
